@@ -11,6 +11,19 @@ sub _decode {
     }
 }
 
+sub _decode_args {
+    my($h, $ie) = @_;
+    for my $key( keys %{$h} ) {
+        if ( ref $h->{$key} eq 'ARRAY' ) {
+            my @values = map { Encode::decode($ie, $_) } @{$h->{$key}};
+            $h->{$key} = \@values;
+        }
+        else {
+            $h->{$key} = Encode::decode($ie, $h->{$key});
+        }
+    }
+}
+
 sub install {
     my( $class, $pkg ) = @_;
     $pkg->add_trigger( init => sub {
@@ -19,6 +32,7 @@ sub install {
         my $ie = $config->{input_encoding} || 'utf-8';
         _decode( $c->req->query_parameters, $ie );
         _decode( $c->req->body_parameters, $ie );
+        _decode_args($c->args, $ie);
         delete $c->req->env->{'plack.request.merged'}; # make sure
     });
     $pkg->add_trigger( pre_finalize => sub {
